var isMatch = function (selector, implementationName, tenantName) {
    var parts = selector.split(':');
    var implementationSelector = parts[0];
    var tenantSelector = parts.length > 1 ? parts[1] : '*';
    return (implementationName === '*' || implementationSelector === implementationName)
        && (tenantName === '*' || tenantSelector === tenantName);
};
/**
 * Get all matching configuration handlers from the specified array.
 * @param handlerArgs An array containing the `arguments` object to read the handlers from.
 * @param implementationName The implementation name to filter on, defaults to '*'.
 * @param tenantName The tenant name to filter on, defaults to '*'.
 */
export default function parseConfigurationHandlers(handlerArgs, implementationName, tenantName) {
    if (implementationName === void 0) { implementationName = '*'; }
    if (tenantName === void 0) { tenantName = '*'; }
    return handlerArgs.filter(function (args) {
        var selector = args[0];
        var handler = args[1];
        if (typeof selector === 'string' && typeof handler === 'function') {
            return isMatch(selector, implementationName, tenantName);
        }
        return false;
    }).map(function (args) { return args[1]; });
}
//# sourceMappingURL=parse-configuration-handlers.js.map